@@ -119,7 +119,7 @@ test -n "$V" || { echo "Could not obtain version in $BUILDDIR." ; exit 1 ; }
 #
 # This is the signing key ID associated with the GitHub account adriaandegroot,
 # which is used to create all "verified" tags in the Calamares repo.
-KEY_ID="128F00873E05AF1D"
+KEY_ID="61A7D26277E4D0DB"
 git tag -u "$KEY_ID" -m "Release v$V" "v$V" || { echo "Could not sign tag v$V." ; exit 1 ; }
 
 ### Create the tarball
