@@ -1,7 +1,7 @@
 /* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2014, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2017-2018, Adriaan de Groot <groot@kde.org>
+ *   Copyright 2017-2020, Adriaan de Groot <groot@kde.org>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -25,20 +25,38 @@
 #include "utils/Logger.h"
 #include "utils/Retranslator.h"
 
+#ifndef WITH_KF5DBus
+#warning "KDSingleApplicationGuard is deprecated"
 #include "3rdparty/kdsingleapplicationguard/kdsingleapplicationguard.h"
+#endif
 
-#include <KF5/KCoreAddons/KAboutData>
+#include <KCoreAddons/KAboutData>
+#ifdef WITH_KF5DBus
+#include <KDBusAddons/KDBusService>
+#endif
 #ifdef WITH_KF5Crash
-#include <KF5/KCrash/KCrash>
+#include <KCrash/KCrash>
 #endif
 
 #include <QCommandLineParser>
 #include <QDebug>
 #include <QDir>
 
+/** @brief Gets debug-level from -D command-line-option
+ *
+ * If unset, use LOGERROR (corresponding to -D1), although
+ * effectively -D2 is the lowest level you can set for
+ * logging-to-the-console, and everything always gets
+ * logged to the session file).
+ */
 static unsigned int
 debug_level( QCommandLineParser& parser, QCommandLineOption& levelOption )
 {
+    if ( !parser.isSet( levelOption ) )
+    {
+        return Logger::LOGERROR;
+    }
+
     bool ok = true;
     int l = parser.value( levelOption ).toInt( &ok );
     if ( !ok || ( l < 0 ) )
@@ -51,7 +69,13 @@ debug_level( QCommandLineParser& parser, QCommandLineOption& levelOption )
     }
 }
 
-static void
+/** @brief Handles the command-line arguments
+ *
+ * Sets up internals for Calamares based on command-line arguments like `-D`,
+ * `-d`, etc. Returns @c true if this is a *debug* run, i.e. if the `-d`
+ * command-line flag is given, @c false otherwise.
+ */
+static bool
 handle_args( CalamaresApplication& a )
 {
     QCommandLineOption debugOption( QStringList { "d", "debug" },
@@ -88,8 +112,8 @@ handle_args( CalamaresApplication& a )
         CalamaresUtils::setXdgDirs();
     }
     CalamaresUtils::setAllowLocalTranslation( parser.isSet( debugOption ) || parser.isSet( debugTxOption ) );
-    Calamares::Settings::init( parser.isSet( debugOption ) );
-    a.init();
+
+    return parser.isSet( debugOption );
 }
 
 int
@@ -117,13 +141,14 @@ main( int argc, char* argv[] )
     // TODO: umount anything in /tmp/calamares-... as an emergency save function
 #endif
 
-    KDSingleApplicationGuard guard( KDSingleApplicationGuard::AutoKillOtherInstances );
-    if ( guard.isPrimaryInstance() )
-    {
-        handle_args( a );
-        return a.exec();
-    }
-    else
+    bool is_debug = handle_args( a );
+
+#ifdef WITH_KF5DBus
+    KDBusService service( is_debug ? KDBusService::Multiple : KDBusService::Unique );
+#else
+    KDSingleApplicationGuard guard( is_debug ? KDSingleApplicationGuard::NoPolicy
+                                             : KDSingleApplicationGuard::AutoKillOtherInstances );
+    if ( !is_debug && !guard.isPrimaryInstance() )
     {
         // Here we have not yet set-up the logger system, so qDebug() is ok
         auto instancelist = guard.instances();
@@ -138,4 +163,9 @@ main( int argc, char* argv[] )
         }
         return 69;  // EX_UNAVAILABLE on FreeBSD
     }
+#endif
+
+    Calamares::Settings::init( is_debug );
+    a.init();
+    return a.exec();
 }
