@@ -1,6 +1,6 @@
-/* === This file is part of Calamares - <http://github.com/calamares> ===
- *
- *   Copyright 2019, Adriaan de Groot <groot@kde.org>
+/* === This file is part of Calamares - <https://github.com/calamares> ===
+ * 
+ *   SPDX-FileCopyrightText: 2019 Adriaan de Groot <groot@kde.org>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -14,6 +14,10 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
+ *
+ *   SPDX-License-Identifier: GPL-3.0-or-later
+ *   License-Filename: LICENSE
+ *
  */
 
 #ifndef GEOIP_HANDLER_H
@@ -43,9 +47,10 @@ class DLLEXPORT Handler
 public:
     enum class Type
     {
-        None,
-        JSON,
-        XML
+        None, // No lookup, returns empty string
+        JSON, // JSON-formatted data, returns extracted field
+        XML,  // XML-formatted data, returns extracted field
+        Fixed // Returns selector string verbatim
     };
 
     /** @brief An unconfigured handler; this always returns errors. */
