@@ -1,5 +1,5 @@
 /* === This file is part of Calamares - <https://github.com/calamares> ===
- * 
+ *
  *   SPDX-FileCopyrightText: 2019 Adriaan de Groot <groot@kde.org>
  *
  *   Calamares is free software: you can redistribute it and/or modify
@@ -23,6 +23,7 @@
 #include "TimeZone.h"
 
 #include "utils/Logger.h"
+#include "utils/String.h"
 
 #include <QFile>
 #include <QStringList>
@@ -156,19 +157,19 @@ TZRegion::fromFile( const char* fileName )
     QTextStream in( &file );
     while ( !in.atEnd() )
     {
-        QString line = in.readLine().trimmed().split( '#', QString::KeepEmptyParts ).first().trimmed();
+        QString line = in.readLine().trimmed().split( '#', SplitKeepEmptyParts ).first().trimmed();
         if ( line.isEmpty() )
         {
             continue;
         }
 
-        QStringList list = line.split( QRegExp( "[\t ]" ), QString::SkipEmptyParts );
+        QStringList list = line.split( QRegExp( "[\t ]" ), SplitSkipEmptyParts );
         if ( list.size() < 3 )
         {
             continue;
         }
 
-        QStringList timezoneParts = list.at( 2 ).split( '/', QString::SkipEmptyParts );
+        QStringList timezoneParts = list.at( 2 ).split( '/', SplitSkipEmptyParts );
         if ( timezoneParts.size() < 2 )
         {
             continue;
