@@ -1,12 +1,12 @@
 /* === This file is part of Calamares - <https://github.com/calamares> ===
- *
- *   Copyright 2013-2016, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2018, Adriaan de Groot <groot@kde.org>
+ * 
+ *   SPDX-FileCopyrightText: 2013-2016 Teo Mrnjavac <teo@kde.org>
+ *   SPDX-FileCopyrightText: 2018 Adriaan de Groot <groot@kde.org>
  *
  *   Originally from Tomahawk, portions:
- *   Copyright 2010-2011, Christian Muehlhaeuser <muesli@tomahawk-player.org>
- *   Copyright 2010-2011, Leo Franchi <lfranchi@kde.org>
- *   Copyright 2010-2012, Jeff Mitchell <jeff@tomahawk-player.org>
+ *   SPDX-FileCopyrightText: 2010-2011 Christian Muehlhaeuser <muesli@tomahawk-player.org>
+ *   SPDX-FileCopyrightText: 2010-2011 Leo Franchi <lfranchi@kde.org>
+ *   SPDX-FileCopyrightText: 2010-2012 Jeff Mitchell <jeff@tomahawk-player.org>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -20,6 +20,10 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
+ *
+ *   SPDX-License-Identifier: GPL-3.0-or-later
+ *   License-Filename: LICENSE
+ *
  */
 
 #include "Dirs.h"
@@ -42,7 +46,6 @@ namespace CalamaresUtils
 {
 
 static QDir s_appDataDir( CMAKE_INSTALL_FULL_DATADIR );
-static QDir s_qmlModulesDir( QString( CMAKE_INSTALL_FULL_DATADIR ) + "/qml" );
 static bool s_isAppDataDirOverridden = false;
 
 static bool s_haveExtraDirs = false;
@@ -79,13 +82,6 @@ isWritableDir( const QDir& dir )
 }
 
 
-QDir
-qmlModulesDir()
-{
-    return s_qmlModulesDir;
-}
-
-
 void
 setAppDataDir( const QDir& dir )
 {
@@ -200,11 +196,4 @@ appLogDir()
     return QDir::temp();
 }
 
-
-void
-setQmlModulesDir( const QDir& dir )
-{
-    s_qmlModulesDir = dir;
-}
-
 }  // namespace CalamaresUtils
