@@ -83,7 +83,9 @@ public:
         SidebarBackground,
         SidebarText,
         SidebarTextSelect,
-        SidebarTextHighlight
+        SidebarTextSelected = SidebarTextSelect,  // TODO:3.3:Remove SidebarTextSelect
+        SidebarTextHighlight,
+        SidebarBackgroundSelected = SidebarTextHighlight  // TODO:3.3:Remove SidebarTextHighlight
     };
     Q_ENUM( StyleEntry )
 
