@@ -35,6 +35,15 @@ namespace Calamares
  * This is generally a **base** class for other view steps, but
  * it can be used stand-alone for viewsteps that don't really have
  * any functionality.
+ *
+ * Most subclasses will override the following methods:
+ * - prettyName() to provide a meaningful human-readable name
+ * - jobs() if there is real work to be done during installation
+ * - getConfig() to return a meaningful configuration object
+ *
+ * For details on the interaction between the config object and
+ * the QML in the module, see the module documentation:
+ *      src/modules/README.md
  */
 class QmlViewStep : public Calamares::ViewStep
 {
@@ -55,6 +64,7 @@ public:
     virtual QString prettyName() const override;
 
     virtual QWidget* widget() override;
+    virtual QSize widgetMargins( Qt::Orientations panelSides ) override;
 
     virtual bool isNextEnabled() const override;
     virtual bool isBackEnabled() const override;
