@@ -21,27 +21,22 @@
  *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <cmath>
-
 #include "locale/TimeZone.h"
 #include "utils/Logger.h"
 
 #include "timezonewidget.h"
 
-// Pixel value indicating that a spot is outside of a zone
-#define RGB_TRANSPARENT 0
-
-static constexpr double MAP_Y_OFFSET = 0.125;
-static constexpr double MAP_X_OFFSET = -0.0370;
-constexpr static double MATH_PI = 3.14159265;
+#include <QMouseEvent>
+#include <QPainter>
 
 #ifdef DEBUG_TIMEZONES
 // Adds a label to the timezone with this name
-constexpr static QLatin1String ZONE_NAME( "zone" );
+#define ZONE_NAME QStringLiteral( "zone" )
 #endif
 
 TimeZoneWidget::TimeZoneWidget( QWidget* parent )
     : QWidget( parent )
+    , timeZoneImages( TimeZoneImageList::fromQRC() )
 {
     setMouseTracking( false );
     setCursor( Qt::PointingHandCursor );
@@ -54,32 +49,10 @@ TimeZoneWidget::TimeZoneWidget( QWidget* parent )
     background = QImage( ":/images/bg.png" );
     pin = QImage( ":/images/pin.png" );
 
-#ifdef DEBUG_TIMEZONES
-    if ( background.size() != QSize( 780, 340 ) )
-    {
-        cWarning() << "Timezone background size mitsmatch" << background.size();
-    }
-#endif
-
     // Set size
     setMinimumSize( background.size() );
     setMaximumSize( background.size() );
-
-    // Zone images
-    for ( const auto* zoneName :
-          { "0.0",  "1.0",  "2.0",  "3.0",  "3.5",  "4.0",  "4.5",  "5.0",  "5.5",   "5.75", "6.0",   "6.5",  "7.0",
-            "8.0",  "9.0",  "9.5",  "10.0", "10.5", "11.0", "11.5", "12.0", "12.75", "13.0", "-1.0",  "-2.0", "-3.0",
-            "-3.5", "-4.0", "-4.5", "-5.0", "-5.5", "-6.0", "-7.0", "-8.0", "-9.0",  "-9.5", "-10.0", "-11.0" } )
-    {
-        timeZoneImages.append( QImage( QStringLiteral( ":/images/timezone_" ) + zoneName + ".png" ) );
-#ifdef DEBUG_TIMEZONES
-        if ( timeZoneImages.last().size() != background.size() )
-        {
-            cWarning() << "Timezone image size mismatch" << zoneName << timeZoneImages.last().size();
-        }
-        timeZoneImages.last().setText( ZONE_NAME, zoneName );
-#endif
-    }
+    setSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed );
 }
 
 
@@ -111,39 +84,12 @@ TimeZoneWidget::setCurrentLocation( const CalamaresUtils::Locale::TZZone* locati
     QPoint pos = getLocationPosition( location );
 
 #ifdef DEBUG_TIMEZONES
-    cDebug() << "Setting location" << location->region() << location->zone() << '(' << location->country() << '@' << location->latitude() << 'N' << location->longitude() << 'E' << ')';
+    cDebug() << "Setting location" << location->region() << location->zone() << '(' << location->country() << '@'
+             << location->latitude() << 'N' << location->longitude() << 'E' << ')';
     cDebug() << Logger::SubEntry << "pixel x" << pos.x() << "pixel y" << pos.y();
-
-    bool found = false;
 #endif
 
-
-    for ( int i = 0; i < timeZoneImages.size(); ++i )
-    {
-        QImage zone = timeZoneImages[ i ];
-
-        // If not transparent set as current
-        if ( zone.pixel( pos ) != RGB_TRANSPARENT )
-        {
-#ifdef DEBUG_TIMEZONES
-            // Log *all* the zones that contain this point,
-            // but only pick the first.
-            if ( !found )
-            {
-                currentZoneImage = zone;
-                found = true;
-                cDebug() << Logger::SubEntry << "First zone found" << i << zone.text( ZONE_NAME );
-            }
-            else
-            {
-                cDebug() << Logger::SubEntry << "Also in zone" << i << zone.text( ZONE_NAME );
-            }
-#else
-            currentZoneImage = zone;
-            break;
-#endif
-        }
-    }
+    currentZoneImage = timeZoneImages.find( pos );
 
     // Repaint widget
     repaint();
@@ -155,83 +101,9 @@ TimeZoneWidget::setCurrentLocation( const CalamaresUtils::Locale::TZZone* locati
 //### Private
 //###
 
-
-QPoint
-TimeZoneWidget::getLocationPosition( double longitude, double latitude )
-{
-    const int width = this->width();
-    const int height = this->height();
-
-    double x = ( width / 2.0 + ( width / 2.0 ) * longitude / 180.0 ) + MAP_X_OFFSET * width;
-    double y = ( height / 2.0 - ( height / 2.0 ) * latitude / 90.0 ) + MAP_Y_OFFSET * height;
-
-    // Far north, the MAP_Y_OFFSET no longer holds, cancel the Y offset; it's noticeable
-    // from 62 degrees north, so scale those 28 degrees as if the world is flat south
-    // of there, and we have a funny "rounded" top of the world. In practice the locations
-    // of the different cities / regions looks ok -- at least Thule ends up in the right
-    // country, and Inuvik isn't in the ocean.
-    if ( latitude > 70.0 )
-    {
-        y -= sin( MATH_PI * ( latitude - 70.0 ) / 56.0 ) * MAP_Y_OFFSET * height * 0.8;
-    }
-    if ( latitude > 74.0 )
-    {
-        y += 4;
-    }
-    if ( latitude > 69.0 )
-    {
-        y -= 2;
-    }
-    if ( latitude > 59.0 )
-    {
-        y -= 4 * int( ( latitude - 54.0 ) / 5.0 );
-    }
-    if ( latitude > 54.0 )
-    {
-        y -= 2;
-    }
-    if ( latitude > 49.0 )
-    {
-        y -= int( ( latitude - 44.0 ) / 5.0 );
-    }
-    // Far south, some stretching occurs as well, but it is less pronounced.
-    // Move down by 1 pixel per 5 degrees past 10 south
-    if ( latitude < 0 )
-    {
-        y += int( ( -latitude ) / 5.0 );
-    }
-    // Antarctica isn't shown on the map, but you could try clicking there
-    if ( latitude < -60 )
-    {
-        y = height - 1;
-    }
-
-    if ( x < 0 )
-    {
-        x = width + x;
-    }
-    if ( x >= width )
-    {
-        x -= width;
-    }
-    if ( y < 0 )
-    {
-        y = height + y;
-    }
-    if ( y >= height )
-    {
-        y -= height;
-    }
-
-    return QPoint( int( x ), int( y ) );
-}
-
-
 void
 TimeZoneWidget::paintEvent( QPaintEvent* )
 {
-    const int width = this->width();
-    const int height = this->height();
     QFontMetrics fontMetrics( font );
     QPainter painter( this );
 
@@ -252,19 +124,16 @@ TimeZoneWidget::paintEvent( QPaintEvent* )
         QPen p( y_lat ? Qt::black : Qt::red );
         p.setWidth( 0 );
         painter.setPen( p );
-        QPoint latLine0( getLocationPosition( 0, y_lat ) );
-        int llx = latLine0.x() + ( ( y_lat & 1 ) ? -10 : 0 );
-        int lly = latLine0.y();
-
-        for ( int c = 0; c < width; ++c )
-        {
-            painter.drawPoint( c, lly );
-        }
+        QPoint latLine0( TimeZoneImageList::getLocationPosition( 0, y_lat ) );
+        painter.drawLine( 0, latLine0.y(), this->width() - 1, latLine0.y() );
     }
     // Just a dot in the selected location, no label
     painter.setPen( Qt::red );
     painter.drawPoint( point );
 #else
+    const int width = this->width();
+    const int height = this->height();
+
     // Draw pin at current location
     QPoint point = getLocationPosition( m_currentLocation );
 
@@ -335,7 +204,7 @@ TimeZoneWidget::mousePressEvent( QMouseEvent* event )
                 const auto* zone = dynamic_cast< const TZZone* >( zone_p );
                 if ( zone )
                 {
-                    QPoint locPos = getLocationPosition( zone->longitude(), zone->latitude() );
+                    QPoint locPos = TimeZoneImageList::getLocationPosition( zone->longitude(), zone->latitude() );
 
                     if ( ( abs( mX - locPos.x() ) + abs( mY - locPos.y() ) < abs( mX - nX ) + abs( mY - nY ) ) )
                     {
