@@ -52,7 +52,7 @@ public:
         CalamaresUtils::Partition::PartitionSize partMaxSize;
 
         /// @brief All-zeroes PartitionEntry
-        PartitionEntry() {}
+        PartitionEntry();
         /// @brief Parse @p size, @p min and @p max to their respective member variables
         PartitionEntry( const QString& size, const QString& min, const QString& max );
 
