@@ -25,6 +25,7 @@
 #include "partition/PartitionIterator.h"
 #include "partition/Sync.h"
 #include "utils/Logger.h"
+#include "utils/String.h"
 
 // KPMcore
 #include <kpmcore/core/device.h>
@@ -73,7 +74,7 @@ getPartitionsForDevice( const QString& deviceName )
         {
             // The fourth column (index from 0, so index 3) is the name of the device;
             // keep it if it is followed by something.
-            QStringList columns = in.readLine().split( ' ', QString::SkipEmptyParts );
+            QStringList columns = in.readLine().split( ' ', SplitSkipEmptyParts );
             if ( ( columns.count() >= 4 ) && ( columns[ 3 ].startsWith( deviceName ) )
                  && ( columns[ 3 ] != deviceName ) )
             {
