@@ -1,20 +1,9 @@
 /* === This file is part of Calamares - <https://github.com/calamares> ===
  *
- *   Copyright 2014-2016, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2018, Adriaan de Groot <groot@kde.org>
- *
- *   Calamares is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
- *
- *   Calamares is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
+ *   SPDX-FileCopyrightText: 2014-2016 Teo Mrnjavac <teo@kde.org>
+ *   SPDX-FileCopyrightText: 2018 Adriaan de Groot <groot@kde.org>
+ *   SPDX-License-Identifier: GPL-3.0-or-later
+ *   License-Filename: LICENSE
  */
 
 #include "CreateUserJob.h"
@@ -114,9 +103,13 @@ CreateUserJob::exec()
         it->truncate( indexOfFirstToDrop );
     }
 
-    foreach ( const QString& group, m_defaultGroups )
+    for ( const QString& group : m_defaultGroups )
+    {
         if ( !groupsLines.contains( group ) )
+        {
             CalamaresUtils::System::instance()->targetEnvCall( { "groupadd", group } );
+        }
+    }
 
     QString defaultGroups = m_defaultGroups.join( ',' );
     if ( m_autologin )
