@@ -22,9 +22,9 @@
 #include "checker/GeneralRequirements.h"
 
 #include "locale/LabelModel.h"
+#include "utils/Dirs.h"
 #include "utils/Logger.h"
 #include "utils/Variant.h"
-#include "utils/Dirs.h"
 
 #include "Branding.h"
 #include "modulesystem/ModuleManager.h"
@@ -33,62 +33,57 @@
 CALAMARES_PLUGIN_FACTORY_DEFINITION( WelcomeQmlViewStepFactory, registerPlugin< WelcomeQmlViewStep >(); )
 
 WelcomeQmlViewStep::WelcomeQmlViewStep( QObject* parent )
-: Calamares::QmlViewStep(parent )
-	, m_config( new Config( this ) ) // the qml singleton takes ownership and deletes it
-//     , m_nextEnabled( false )
+    : Calamares::QmlViewStep( parent )
+    , m_config( new Config( this ) )
     , m_requirementsChecker( new GeneralRequirements( this ) )
-
 {
-// 	connect( m_config,
-//              &Config::isNextEnabledChanged,
-// 			 this,
-// 			 &WelcomeQmlViewStep::nextStatusChanged );
-//     emit nextStatusChanged(true);
+    connect( Calamares::ModuleManager::instance(),
+            &Calamares::ModuleManager::requirementsComplete,
+            this,
+            &WelcomeQmlViewStep::nextStatusChanged );
 }
 
 
 QString
 WelcomeQmlViewStep::prettyName() const
 {
-	return tr( "Welcome" );
+    return tr( "Welcome" );
 }
 
 bool
 WelcomeQmlViewStep::isNextEnabled() const
 {
-	// TODO: should return true
-//     return m_config->property("isNextEnabled").toBool();
-    return true;
+    return m_config->requirementsModel()->satisfiedMandatory();
 }
 
 bool
 WelcomeQmlViewStep::isBackEnabled() const
 {
-	// TODO: should return true (it's weird that you are not allowed to have welcome *after* anything
-	return false;
+    // TODO: should return true (it's weird that you are not allowed to have welcome *after* anything
+    return false;
 }
 
 
 bool
 WelcomeQmlViewStep::isAtBeginning() const
 {
-	// TODO: adjust to "pages" in the QML
-	return true;
+    // TODO: adjust to "pages" in the QML
+    return true;
 }
 
 
 bool
 WelcomeQmlViewStep::isAtEnd() const
 {
-	// TODO: adjust to "pages" in the QML
-	return true;
+    // TODO: adjust to "pages" in the QML
+    return true;
 }
 
 
 Calamares::JobList
 WelcomeQmlViewStep::jobs() const
 {
-	return Calamares::JobList();
+    return Calamares::JobList();
 }
 
 void
@@ -96,30 +91,29 @@ WelcomeQmlViewStep::setConfigurationMap( const QVariantMap& configurationMap )
 {
     m_config->setConfigurationMap( configurationMap );
 
-	// TODO: figure out how the requirements (held by ModuleManager) should be accessible
-	//          to QML as a model. //will be model as a qvariantmap containing a alert level and the message string
-	if ( configurationMap.contains( "requirements" )
-		 && configurationMap.value( "requirements" ).type() == QVariant::Map )
-	{
-		m_requirementsChecker->setConfigurationMap( configurationMap.value( "requirements" ).toMap() );
-	}
-	else
-		cWarning() << "no valid requirements map found in welcome "
-					  "module configuration.";
+    if ( configurationMap.contains( "requirements" )
+         && configurationMap.value( "requirements" ).type() == QVariant::Map )
+    {
+        m_requirementsChecker->setConfigurationMap( configurationMap.value( "requirements" ).toMap() );
+    }
+    else
+    {
+        cWarning() << "no valid requirements map found in welcomeq "
+                      "module configuration.";
+    }
 
-    Calamares::QmlViewStep::setConfigurationMap( configurationMap ); // call parent implementation last
+    Calamares::QmlViewStep::setConfigurationMap( configurationMap );  // call parent implementation last
     setContextProperty( "Welcome", m_config );
 }
 
 Calamares::RequirementsList
 WelcomeQmlViewStep::checkRequirements()
 {
-	return m_requirementsChecker->checkRequirements();
+    return m_requirementsChecker->checkRequirements();
 }
 
 QObject*
 WelcomeQmlViewStep::getConfig()
 {
-	return m_config;
+    return m_config;
 }
-
